#!/usr/bin/env bash

# ----------------------------------------------------------- #
# Copyright (C) 2008 Red Hat, Inc.                            #
# Written by Michel Samia <msamia@redhat.com>                 #
# logfiles.sh                                                 #
# secTool script testing presence of some logfiles            #
# more info in logfiles.dsc                                   #
# ----------------------------------------------------------- #


if (( ${DEBUG} == 1 )); then 
. "${TESTS_DIRS}/bash_defs_debug.sh" 
else
. "${TESTS_DIRS}/bash_defs.sh"
fi

if (( ${REFRESH} == 1 )); then
    test_exit ${E_OK}
fi

E_DOESNT_EXIST=1
E_WRONG_OWNER=2
E_WRONG_GROUP=3
E_WRONG_PERM=4


echo "$LOGFILES" |
{
	while read file owner group perm
	do
	    # report 'INFO' $E_DOESNT_EXIST "Checking file \$file"
 
	    # exists?
	    if ! [[ -f $file ]]
		then
			report 'WARNING' $E_DOESNT_EXIST "File \$file doesn't exist!"
			report 'HINT' $E_DOESNT_EXIST "Please create this file."
	    else
			# owner
			if [[ "`stat -c '%U' $file`" != "$owner" ]]
			then
				report 'ERROR' $E_WRONG_OWNER "File \$file has wrong owner. The correct owner is \$owner."
				report 'HINT' $E_WRONG_OWNER "Please change the owner of this file to the recommended one."
			fi

			# group	
			if [[ "`stat -c '%G' $file`" != "$group" ]]
			then
				report 'ERROR' $E_WRONG_GROUP "File \$file has wrong group. The correct group is \$group."
				report 'HINT' $E_WRONG_GROUP "Please change the group of this file to the recommended one."
			fi
				
			# permission
		
			if [[ "`stat -c '%a' $file`" != "$perm" ]]
			then
				report 'ERROR' $E_WRONG_PERM "File \$file has wrong permssions! The correct permissions are \$perm."
				report 'HINT' $E_WRONG_PERM "Please change the permissions of this file to the recommended value."
			fi
		fi
	done
}
